"""
frontend
- ⭐️ https://jmvalin.ca/demo/rnnoise/
- ⭐️ A Hybrid DSP/Deep Learning Approach to Real-Time Full-Band Speech Enhancement](https://arxiv.org/abs/1709.08243)
- https://gitlab.xiph.org/xiph/rnnoise or https://github.com/xiph/rnnoise.git
- https://github.com/werman/noise-suppression-for-voice (rnnoise c++ binding)
- https://github.com/pengzhendong/pyrnnoise (rnnoise python ctypes binding)
"""
